{% extends 'dashboard/layout.html' %}
{% load url from future %}
{% load i18n %}

{% block title %}
    {% trans "Datacash transaction" %} {{ txn.datacash_reference }} | {{ block.super }}
{% endblock %}

{% block breadcrumbs %}
<ul class="breadcrumb">
    <li>
        <a href="{% url 'dashboard:index' %}">{% trans "Dashboard" %}</a>
        <span class="divider">/</span>
    </li>
    <li>
        <a href="{% url 'datacash-transaction-list' %}">{% trans "Datacash" %}</a>
        <span class="divider">/</span>
    </li>
	<li class="active">{{ txn.datacash_reference }}</li>
</ul>
{% endblock %}

{% block headertext %}
{% trans "Transaction" %} {{ txn.datacash_reference }}
{% endblock %}

{% block dashboard_content %}
    <table class="table table-striped table-bordered">
        <tbody>
            <tr><th>{% trans "Datacash reference" %}</th><td>{{ txn.datacash_reference }}</td></tr>
            <tr><th>{% trans "Order number" %}</th><td>{{ txn.order_number }}</td></tr>
            <tr><th>{% trans "Method" %}</th><td>{{ txn.method }}</td></tr>
            <tr><th>{% trans "Amount" %}</th><td>{{ txn.amount }}</td></tr>
            <tr><th>{% trans "Currency" %}</th><td>{{ txn.currency }}</td></tr>
            <tr><th>{% trans "Merchant reference" %}</th><td>{{ txn.merchant_reference }}</td></tr>
            <tr><th>{% trans "Auth code" %}</th><td>{{ txn.auth_code|default:"-" }}</td></tr>
            <tr><th>{% trans "Status" %}</th><td>{{ txn.status }}</td></tr>
            <tr><th>{% trans "Reason" %}</th><td>{{ txn.reason }}</td></tr>
            <tr><th>{% trans "Request XML" %}</th><td><pre>{{ txn.pretty_request_xml }}</pre></td></tr>
            <tr><th>{% trans "Response XML" %}</th><td><pre>{{ txn.pretty_response_xml }}</pre></td></tr>
            <tr><th>{% trans "Date" %}</th><td>{{ txn.date_created }}</td></tr>
        </tbody>
    </table>
{% endblock dashboard_content %}
